#
# spec file for package pantheon-calculator
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.calculator
Name:           pantheon-calculator
Version:        8.0.0
Release:        1.2
Summary:        A simple calculator for the Pantheon Desktop
License:        GPL-3.0-only
URL:            https://github.com/elementary/calculator
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.28.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
Provides:       elementary-calculator = %{version}
Obsoletes:      elementary-calculator < %{version}

%description
A tiny, simple calculator written in GTK+ and Vala.

%lang_package

%prep
%autosetup -n calculator-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.svg
%dir %{_datadir}/icons/hicolor/{128x128@2,128x128@2/apps,16x16@2,16x16@2/apps,24x24@2,24x24@2/apps,32x32@2,32x32@2/apps,64x64@2,64x64@2/apps}

%files lang -f %{appid}.lang

%changelog
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-calculator
- remove %%suse_update_desktop_file, as it's deprecated
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- enable leap by using datadir/icons
* Sun Aug 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Updated translations
- update to 2.0.3:
  * Branding color changed to Mint 500
  * Updated translations
- update to 2.0.2:
  * copy entry content on Ctrl+C
  * paste into entry on Ctrl+V
  * fix meson warnings
  * Metainfo improvements
- update to 2.0.1:
  * Redesigned app icon
  * Flat titlebar
  * Updated translations
- update to 2.0.0:
  * Update to gtk4
  * Updated translations
- update to 1.7.2:
  * Updated translations
- update to 1.7.1:
  * Show advanced controls only affects the focused window
  * Focus the main text entry on startup
  * Show the correct window title in Multitask view
  * Updated translations
  * Added 'New Window' Desktop Action
- update to 1.7.0:
  * Add a "Clear History" button to the history dialog
  * Updated translations
- update to 1.6.2:
  * Updated translations
- update to 1.6.1:
  * Fixed an issue with multiple windows
  * More informative copy in history dialog
  * Updated translations
- update to 1.6.0:
  * Add log and inverse trigonometric functions
  * Fix an issue with negative decimals without leading digits
  * More efficient state saving
  * Use slim titlebar
  * Updated translations
- update to 1.5.5:
  * Fix inserting multi-byte characters
  * Updated translations
- switch url to github, as we don't want to link to a different OS
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.4:
  * Release 1.5.3 (#117)
  * Travis: Downgrade node to 10
  * AppData: Add 1.5.3 release data
  * Add Release to Actions
  * Add Gettext Updates to Actions
  * Add Lint to CI (#113)
  * Evaluation: Fix variable naming convention
  * Lint src and test (#111)
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml (#112)
  * MainWindow: Use GLib.Action for clear (#104)
  * MainWindow: Animate infobar hide/show (#106)
  * Fix for selection and replace (#102)
  * Added flatpak manifest (#101)
  * Use Granite style constants (#105)
  * MainWindow: Get rid of single-use methods (#103)
  * Add keywords to desktop file (continued) (#89)
  * Fix #88 and #92 by changing decimal key behavior (#94)
  * Create FUNDING.yml
  * Remove unused po files and update LINGUAS
  * Merge branch 'origin/master' into Weblate.
* Tue Mar 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.2:
  * Travis.yml: Update Houston CI (#87)
  * Add missing languages to LINGUAS files (#86)
  * Added pt_BR to LINGUAS in extra folder (#85)
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.5.1:
  * Merge branch 'origin/master' into Weblate
  * Add pt and pt_BR to LINGUAS (#84)
  * Use Gtk.Application (#83)
  * Test with Houston CI (#63)
  * AppData: Remove .desktop from app ID (#78)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.1.5:
  * Merge branch 'origin/master' into Weblate
  * Simplify Calculator Core (#72)
  * Add missing LINGUAS
  * Merge remote-tracking branch 'origin/master'
  * Changed the type of Gtk.MessageType for the infobar to
    WARNING instead of ERROR (#70)
* Sat Jun  9 2018 avvissu@yandex.by
- Update to 0.1.4:
  * Fix separator bugs (#56)
  * Add editorconfig file (#67)
  * Fix deprecated warning with action accel (#66)
  * Add OARS data (#64)
  * Set same height for all rows (#62)
  * fix next minus number / operator bug, add tests (#60)
  * Copyright header & code style (#58)
  * Use GLib.Queue instead of own Stack class (#54)
  * Code style (#51)
  * Add tests for calculator core (#50)
  * Merge remote-tracking branch 'origin/master'
* Fri Jun  8 2018 avvissu@yandex.by
- Rename to elementary-calculator
- Switch to git from bzr
- Switch to meson
- Build with dependences: AppStream
- Remove obsolete macros
- Spec file cleanup
* Mon Aug 14 2017 avvissu@yandex.by
- Update to 0.1.3:
  * Set has_subtitle to false (#28)
  * RDNN most of the things (#29)
  * Fixes occasional result of -0 (#26)
  * Update issues URL (#27)
  * Screenshot (#25)
  * remove about dialog (#24)
  * Create CODE_OF_CONDUCT.md (#19)
- Change the sourceurl to git
* Fri Jan 20 2017 avvissu@yandex.by
- Update to 0.1.2:
  * Launchpad automatic translations update.
  * Fix multiple calculators being always displaying the same
    content as others
  * Ctrl+Q for quitting, remember window position.
  * Set basic grid alignment to FILL
  * Vertically center and expand the entry
* Sat Sep 10 2016 mailaender@opensuse.org
- update to version 0.1.1
* Tue Sep  1 2015 and.november@opensuse.org
- initial package (version 0.1.0) for build.opensuse.org
